<?php

namespace FiloBlu\Refilo\Controller\Adminhtml\Exporter;

use Exception;
use Magento\Framework\App\Action\HttpGetActionInterface as HttpGetActionInterface;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Message\ManagerInterface;
use FiloBlu\Refilo\Model\Exporter\Translations as TranslationsBlock;

class Translations implements HttpGetActionInterface
{
    /**
     * @var
     */
    private $messageManager;
    /**
     * @var ResultFactory
     */
    private $resultFactory;
    /**
     * @var TranslationsBlock
     */
    private $translations;


    /**
     * Countries constructor.
     * @param ResultFactory $resultFactory
     * @param ManagerInterface $messageManager
     * @param TranslationsBlock $translations
     */
    public function __construct(
        ResultFactory $resultFactory,
        ManagerInterface $messageManager,
        TranslationsBlock $translations
    ) {
        $this->resultFactory = $resultFactory;
        $this->messageManager = $messageManager;
        $this->translations = $translations;
    }

    public function execute()
    {
        try {
            //@ToDo Reimplement it as query as soon as a solution for regions is found
            $this->translations->exportTranslations();
            $this->messageManager->addSuccessMessage(__('Translations successfully synced with MongoDB'));
        } catch (LocalizedException $e) {
            $this->messageManager->addErrorMessage($e->getMessage());
        } catch (Exception $e) {
            $this->messageManager->addExceptionMessage($e, __('An error occurred while syncing data with MongoDB.'));
        }

        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        return $resultRedirect->setPath('indexer/indexer/list/');
    }

}
