<?php

namespace FiloBlu\Refilo\Model\Indexer\Core;

use FiloBlu\Refilo\Model\Adapter\Mongo;
use FiloBlu\Refilo\Model\Indexer\Core\Provider\QueryProviderInterface;
use FiloBlu\Refilo\Model\Indexer\Core\Provider\QueryProviderInterfaceFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\StoreManagerInterface;

class BaseStoreProcessor extends BaseMongoIndexer
{
    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    /**
     * BaseWebsiteProcessor constructor.
     * @param SqlToMongoAdapterInterface $sqlToMongoAdapter
     * @param QueryProviderInterfaceFactory $queryProviderFactory
     * @param ScopeConfigInterface $scopeConfig
     * @param StoreManagerInterface $storeManager
     * @param Mongo $mongo
     * @param string $mongoKey
     * @param string $mongoCollection
     * @param bool $insertMode
     * @param string $databaseConfigurationKey
     */
    public function __construct(
        SqlToMongoAdapterInterface $sqlToMongoAdapter,
        QueryProviderInterfaceFactory $queryProviderFactory,
        ScopeConfigInterface $scopeConfig,
        StoreManagerInterface $storeManager,
        Mongo $mongo,
        string $mongoKey,
        string $mongoCollection,
        bool $insertMode,
        string $databaseConfigurationKey
    ) {
        parent::__construct(
            $sqlToMongoAdapter,
            $queryProviderFactory,
            $scopeConfig,
            $mongo,
            $mongoKey,
            $mongoCollection,
            $insertMode,
            $databaseConfigurationKey
        );
        $this->storeManager = $storeManager;
    }

    protected function performAction($ids = null)
    {
        foreach ($this->storeManager->getStores() as $store) {
            /** @var QueryProviderInterface $provider */
            $provider = $this->queryProviderFactory->create();
            if ($ids) {
                $provider->filter($ids);
            }
            $provider->store($store->getId());
            $result = $this->sqlToMongoAdapter->adaptFromSql($provider);
            $this->mongo->update(
                $this->getMongoKey(),
                $result,
                sprintf(
                    $this->getTargetMongoCollection(),
                    $store->getCode()
                ),
                $this->getInsertMode(),
                $this->getMongoDb()
            );
        }
    }
}
